@@ -13,7 +13,10 @@ from decimal import Decimal
 from flask.templating import render_template as flask_render_template
 from jinja2 import BaseLoader, TemplateNotFound, nodes
 from jinja2.ext import Extension
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
 
+from .contrib import gravatar
 from .globals import request
 from .helpers import _rst_to_html_filter, make_crumbs
 
@@ -28,6 +31,7 @@ def nereid_default_template_ctx_processor():
 
 NEREID_TEMPLATE_FILTERS = dict(
     rst = _rst_to_html_filter,
+    gravatar = gravatar.url,
 )
 
 def render_template(template_name, _prefix_website=True, **context):
@@ -138,3 +142,50 @@ class FragmentCacheExtension(Extension):
         rv = caller()
         self.environment.fragment_cache.add(key, rv, timeout)
         return rv
+
+
+def render_email(from_email, to, subject,
+        text_template=None, html_template=None, cc=None, **context):
+    """Read the templates for email messages, format them, construct
+    the email from them and return the corresponding email message
+    object.
+
+    :param from_email: Email From
+    :param to: Email IDs of direct recepients
+    :param subject: Email subject
+    :param text_template: <Text email template path>
+    :param html_template: <HTML email template path>
+    :param cc: Email IDs of Cc recepients
+    :param context: Context to be sent to template rendering
+
+    :return: Email multipart instance or Text/HTML part
+    """
+    if not (text_template or html_template):
+        raise Exception("Atleast HTML or TEXT template is required")
+        
+    # Create the body of the message (a plain-text and an HTML version).
+    # text is your plain-text email
+    # html is your html version of the email
+    # if the reciever is able to view html emails then only the html
+    # email will be displayed
+    msg = MIMEMultipart('alternative')
+    if text_template:
+        text = render_template(text_template, **context)
+        text_part = MIMEText(text.encode("utf-8"), 'plain', _charset="UTF-8")
+        msg.attach(text_part)
+    if html_template:
+        html = render_template(html_template, **context)
+        html_part = MIMEText(html.encode("utf-8"), 'html', _charset="UTF-8")
+        msg.attach(html_part)
+        
+    if text_template and not html_template:
+        msg = text_part
+    elif html_template and not text_template:
+        msg = html_part
+
+    msg['Subject'] = subject
+    msg['From'] = from_email
+    msg['To'] = to
+    msg['Cc'] = cc or ''
+
+    return msg
