@@ -3,8 +3,8 @@
 
 {
     'name': 'Nereid',
-    'version': '2.4.0.4',
-    'author': 'Openlabs Technologies & Consulting',
+    'version': '2.4.0.5',
+    'author': 'Openlabs Technologies & Consulting (P) Limited',
     'email': 'info@openlabs.co.in',
     'website': 'http://www.openlabs.co.in/',
     'description': '''Base configuration of Nereid:
@@ -15,7 +15,6 @@
         'ir',
         'res',
         'company',
-        'electronic_mail_template',
     ],
     'xml': [
        'defaults.xml',
