@@ -10,6 +10,7 @@
 """
 from ast import literal_eval
 
+import pytz
 from werkzeug import abort, redirect
 from wtforms import Form, TextField, PasswordField, validators
 
@@ -156,6 +157,13 @@ class WebSite(ModelSQL, ModelView):
         'nereid.user', 'Guest user', required=True
     )
 
+    timezone = fields.Selection(
+        [(x, x) for x in pytz.common_timezones], 'Timezone', translate=False
+    )
+
+    def default_timezone(self):
+        return 'UTC'
+
     def default_active(self):
         return True
 
@@ -409,7 +417,7 @@ class WebSite(ModelSQL, ModelView):
         else:
             rv.update({
                 'logged_in': True,
-                'name': request.nereid_user.name
+                'name': request.nereid_user.display_name
                 })
         return rv
 
